% Plot Gauss-Legendre quadrature

legInit

% zero crossings of P_5 (computed with Mathematica)
lambdas = [ -0.90618, -0.538469, 0.0, 0.538469, 0.90618];

% generate values
K = zeros( n_leg + 1, n_leg+1);

% construct kernel matrix: 
% - each column is fixed basis function
% - each row is one fixed lambda
for( n = 0 : n_leg)
  coeffs = legendre( n, lambdas, 'norm');
  K(:,n+1) = coeffs(1,:)';  
end

% sampling matrix
% - i-th column is formed by basis function coefficients for i-th dual
%   basis function 
S = inv(K);

% Legendre polynomials are a special case since all but the first basis
% function vanishes
% The constant is the integral of the normalized P_0 function
% Note that to compute the quadrature weights we would not have to compute
% the full inverse since only the first row is relevant 
weights = sqrt(2.0) * S(1,:);

% values of kernel and dual kernel functions
vals_k = zeros( n_leg+1, numel(xvals));
vals_kd = zeros( n_leg+1, numel(xvals));

for( i = 1 : numel(lambdas))
  vals_k(i,:) = legEvalSignal( n_leg, K(i,:), xvals);
  vals_kd(i,:) = legEvalSignal( n_leg, S(:,i)', xvals);
end

%% visualize

legPreVisualization;

% plot corresponding reproducing points
for( i = 1 : numel(lambdas))
  
  col = cols(i,:);
  col( find( col == 0.0)) = 0.8;
  plot( lambdas(i), 0.0, 'x', 'MarkerSize', 10, 'Color', col);
  plot( xvals, vals_kd(i,:), '-', 'Color', col);
  
  plot( [lambdas(i), lambdas(i)], [0.0, 3.0 * weights(i)], '-o', ...
        'Color', cols(i,:), 'LineWidth', 1.25);

end

legPostVisualization; 
ylim( [min( 0.0 , 4.0 * min(weights)), max( 3.0, 4.0 * max(weights))]);  

savePlot( h_fig, 'legPlotGaussLegendre');
