% Plot a biorthogonal basis in R2

%% Construct random biorthogonal basis.

% generate a random, non-orthogonal basis in R2
% B = 1.5 * rand( 2, 2);
% assert( cond( B ) < Inf);
% Fix B for reproducibility
B = [ 0.3240    1.4240; 
      1.1856    0.4913 ];

% dual basis
Bt = inv( B);

% We hence have: 
% \bar{e}_1 = B(1,:);
% \bar{e}_2 = B(2,:);
% \tilde{e}_1 = Bt(:,1);
% \tilde{e}_2 = Bt(:,2);

%% Verify biorthogonality of basis

err_biortho = 0.0;
for( i = 1 : 2) 
  for( j = 1 : 2) 
    
    % compute inner product of primary and dual basis functions
    % < \bar{e}_i , \tilde{e}_j >
    err = dot( B(i,:), Bt(:,j));
    
    % the diagonal terms have to be 1.0 so adjust error
    if( i == j) err = err - 1.0; end
    
    % accumulate error
    err_biortho = err_biortho + err;
  
  end
end

% obviously, this is satisfied by construction since Bt = inv(B), which is
% nothing but the biorthogonality condition written in matrix form
disp( sprintf( 'Total error in biorthogonality: %e', err_biortho));

%% Verify reconstruction for random vector

v = randn(2,1);

% projection
v_1 = dot( Bt(:,1), v);
v_2 = dot( Bt(:,2), v);

% reconstruction
v_rec = v_1 * B(1,:)' + v_2 * B(2,:)';

% reconstruction error
err_reconst = norm( v - v_rec);
disp( sprintf( 'Reconstruction error for basis: %e', err_reconst));

%% Display

figure;
hold on;

% plot basis functions
plotVector( B(1,:), '-r');
plotVector( B(2,:), '--r');

% plot dual basis functions
plotVector( Bt(:,1), '-b');
plotVector( Bt(:,2), '--b');

%legend( {'$\bar{e}_1$', '$\bar{e}_2$', '$\tilde{e}_1$', '$\tilde{e}_2$'}, ...
%         'Location', 'SouthWest') ; %, ...
         %'Interpreter','latex', ...
         %'fontsize', 18);
       
% plot axis
xlim( [-0.4, 1.3]);
ylim( [-0.3, 1.5]);

plot( [-maxval,maxval], [0, 0], 'Color', [0.8, 0.8, 0.8]);
vline( 0.0);  % modified to plot correct color

% widescreen format
set(gca,'DataAspectRatio', [0.5, 1.0, 1.0])
%

% adjust height
rect = get( gcf, 'OuterPosition');
rect(3) = 600;
rect(4) = 500;
set( gcf, 'OuterPosition', rect)


print('-depsc2','./figures/plotBiorthoBasisR2');
